# Python CLI and SDK for Continual

Continual is an operational AI for the modern data stack. Learn more at
https://continual.ai.

## Getting Started

To install the Continual CLI and SDK run:

```
pip3 install continual
```
